@@ -103,10 +103,12 @@ empathy_call_factory_init (EmpathyCallFactory *obj)
         NULL));
 
   tp_base_client_add_handler_capabilities_varargs (client,
-    "org.freedesktop.Telepathy.Channel.Interface.MediaSignalling/ice-udp",
-    "org.freedesktop.Telepathy.Channel.Interface.MediaSignalling/gtalk-p2p",
-    "org.freedesktop.Telepathy.Channel.Interface.MediaSignalling/video/h264",
-    NULL);
+      "org.freedesktop.Telepathy.Channel.Type.Call1/audio",
+      "org.freedesktop.Telepathy.Channel.Type.Call1/video",
+      "org.freedesktop.Telepathy.Channel.Type.Call1/ice",
+      "org.freedesktop.Telepathy.Channel.Type.Call1/gtalk-p2p",
+      "org.freedesktop.Telepathy.Channel.Type.Call1/video/h264",
+      NULL);
 }
 
 static GObject *
